@@ -48,10 +48,11 @@ rand_mvn <- function(n, mean = rep(0, nrow(sigma)), sigma) {
 }
 
 # Kriging Function ------------------------------------------------------------
-# Calculates posterior mean, sigma/s2 and estimate of tau2 using kriging equations
+# Calculates posterior mean, sigma/s2 and estimate of tau2 using kriging 
+# equations
 
-krig <- function(y, dx, d_new = NULL, d_cross = NULL, theta, g, mean = TRUE, s2 = FALSE,
-                 sigma = TRUE, tau2 = TRUE) {
+krig <- function(y, dx, d_new = NULL, d_cross = NULL, theta, g, mean = TRUE, 
+                 s2 = FALSE, sigma = TRUE, tau2 = TRUE) {
   
   if (s2 & sigma) s2 <- FALSE # don't calculate diagonal separately
 
@@ -67,18 +68,18 @@ krig <- function(y, dx, d_new = NULL, d_cross = NULL, theta, g, mean = TRUE, s2
   }
 
   if (mean) {
-    C_cross <- calc_K(d_cross, theta) # nugget not included in rectangular matrix
+    C_cross <- calc_K(d_cross, theta) # g not included in rectangular matrix
     out$mean <- C_cross %*% C_inv %*% y
   }
   
   if (s2) {
-    if (!mean) C_cross <- calc_K(d_cross, theta) # nugget not included in rectangular matrix
+    if (!mean) C_cross <- calc_K(d_cross, theta) # g not included
     C_new <- rep(1 + g, times = nrow(d_new))
     out$s2 <- scale * (C_new - diag(C_cross %*% C_inv %*% t(C_cross)))
   }
 
   if (sigma) {
-    if (!mean) C_cross <- calc_K(d_cross, theta) # nugget not included in rectangular matrix
+    if (!mean) C_cross <- calc_K(d_cross, theta) # g not included
     C_new <- calc_K(d_new, theta, g)
     out$sigma <- scale * (C_new - (C_cross %*% C_inv %*% t(C_cross)))
   }
@@ -107,16 +108,17 @@ invdet <- function(M) {
 #' @title Calculates squared pairwise distances
 #' @description Calculates squared pairwise euclidean distances using C.
 #' 
-#' @details C code derived from the "laGP" package (Robert B Gramacy and Furong Sun).
+#' @details C code derived from the "laGP" package (Robert B Gramacy and 
+#'          Furong Sun).
 #' @param X1 matrix of input locations
-#' @param X2 matrix of second input locations (if \code{NULL}, distance is calculated
-#'        between \code{X1} and itself)
+#' @param X2 matrix of second input locations (if \code{NULL}, distance is 
+#'        calculated between \code{X1} and itself)
 #' @return symmetric matrix of squared euclidean distances
 #' 
 #' @references 
 #' Gramacy, RB and F Sun. (2016). laGP: Large-Scale Spatial Modeling via Local 
-#'     Approximate Gaussian Processes in R. \emph{Journal of Statistical Software 
-#'     72} (1), 1-46. doi:10.18637/jss.v072.i01
+#'     Approximate Gaussian Processes in R. \emph{Journal of Statistical 
+#'     Software 72} (1), 1-46. doi:10.18637/jss.v072.i01
 #' 
 #' @examples 
 #' x <- seq(0, 1, length = 10)
@@ -183,17 +185,17 @@ calc_tau2 <- function(y, x, theta, g) {
 # Calculate Score Function ----------------------------------------------------
 #' @title Calculates score
 #' @description Calculates score (higher scores indicate better fits).  Only 
-#'     applicable to noisy data.  Requires full covariance matrix (e.g. \code{predict} 
-#'     with \code{lite = FALSE}).
+#'     applicable to noisy data.  Requires full covariance matrix (e.g. 
+#'     \code{predict} with \code{lite = FALSE}).
 #'     
 #' @param y response vector
 #' @param mu predicted mean
 #' @param sigma predicted covariance
 #' 
 #' @references 
-#' Gneiting, T, and AE Raftery. 2007. “Strictly Proper Scoring Rules, Prediction, 
-#'     and Estimation.” \emph{Journal of the American Statistical Association 102} 
-#'     (477), 359-378.
+#' Gneiting, T, and AE Raftery. 2007. Strictly Proper Scoring Rules, Prediction, 
+#'     and Estimation. \emph{Journal of the American Statistical Association 
+#'     102} (477), 359-378.
 #' 
 #' @export
 
@@ -208,13 +210,14 @@ score <- function(y, mu, sigma) {
 
 # Calculate RMSE Function -----------------------------------------------------
 #' @title Calculates RMSE
-#' @description Calculates root mean square error (lower RMSE indicate better fits).
+#' @description Calculates root mean square error (lower RMSE indicate better 
+#'     fits).
 #' @param y response vector
 #' @param mu predicted mean
 #' 
 #' @examples
-#' # See "deepgp-package", "fit_one_layer", "fit_two_layer", or "fit_three_layer"
-#' # for an example
+#' # See "deepgp-package", "fit_one_layer", "fit_two_layer", or 
+#' # "fit_three_layer" for an example
 #' 
 #' @export
 
